==> eiffelstudio-18.01.10.1424.tar: F_code/C27/st1326.c <==
/*
 * Code for class STACK [BOOLEAN]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st1326.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {STACK}.replace */
void F425_3833 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3530[dtype-365])(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3512[dtype-365])(Current, (EIF_REFERENCE) &arg1);
	RTLE;
}

/* {STACK}.fill */
void F425_3834 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,738,0,0,0xFFFF};
		EIF_TYPE typres0;
		{
			EIF_TYPE l_type;
			l_type = eif_final_id(Y3378,Y3378_gen_type,Dftype(Current),234);
			typarr0[2] = l_type.annotations | 0xFF00;
			typarr0[3] = l_type.id;
		}
		
		typres0 = eif_compound_id(Dftype(Current), typarr0);
		tr1 = RTLNS(typres0.id, 738, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F730_5316(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	loc1 = (EIF_REFERENCE) tr1;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3481[Dtype(arg1)-285])(RTCW(arg1));
	for (;;) {
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R3480[Dtype(arg1)-261])(RTCW(arg1));
		if (tb1) break;
		tb2 = *(EIF_BOOLEAN *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3479[Dtype(arg1)-285])(RTCW(arg1)));
		F739_5380(RTCW(loc1), tb2);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R3494[Dtype(arg1)-285])(RTCW(arg1));
	}
	for (;;) {
		tb2 = '\01';
		tb3 = F374_3776(RTCW(loc1));
		if (!tb3) {
			tb2 = (EIF_BOOLEAN) !F676_5049(Current);
		}
		if (tb2) break;
		tb3 = F730_5320(RTCW(loc1));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3512[Dtype(Current)-365])(Current, (EIF_REFERENCE) &tb3);
		F739_5383(RTCW(loc1));
	}
	RTLE;
}

void EIF_Minit1326 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C27/st1326.c <==
/*
 * Code for class STACK [INTEGER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st1326.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {STACK}.replace */
void F425_3833 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3530[dtype-365])(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3512[dtype-365])(Current, (EIF_REFERENCE) &arg1);
	RTLE;
}

/* {STACK}.fill */
void F425_3834 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTLD;
	
	RTLI(4);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,738,0,0,0xFFFF};
		EIF_TYPE typres0;
		{
			EIF_TYPE l_type;
			l_type = eif_final_id(Y3378,Y3378_gen_type,Dftype(Current),234);
			typarr0[2] = l_type.annotations | 0xFF00;
			typarr0[3] = l_type.id;
		}
		
		typres0 = eif_compound_id(Dftype(Current), typarr0);
		tr1 = RTLNS(typres0.id, 738, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F728_5317(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	loc1 = (EIF_REFERENCE) tr1;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3481[Dtype(arg1)-285])(RTCW(arg1));
	for (;;) {
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R3480[Dtype(arg1)-261])(RTCW(arg1));
		if (tb1) break;
		ti4_1 = *(EIF_INTEGER_32 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R3479[Dtype(arg1)-285])(RTCW(arg1)));
		F739_5381(RTCW(loc1), ti4_1);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R3494[Dtype(arg1)-285])(RTCW(arg1));
	}
	for (;;) {
		tb2 = '\01';
		tb3 = F373_3776(RTCW(loc1));
		if (!tb3) {
			tb2 = (EIF_BOOLEAN) !F674_5050(Current);
		}
		if (tb2) break;
		ti4_1 = F728_5321(RTCW(loc1));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3512[Dtype(Current)-365])(Current, (EIF_REFERENCE) &ti4_1);
		F739_5384(RTCW(loc1));
	}
	RTLE;
}

void EIF_Minit1326 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
